/* Last modified: January 20, 2015

*--------------------*
*    INPUT FILES     *
*--------------------*

Packages needed: estout - available from within Stata by typing "ssc install estout" or at http://repec.org/bocode/e/estout/esttab.html

Files needed: 

bds.dta - a cleaned version of the Business Dyanamics Statistics, linked to State minimum wage data and other covariates

qcew.dta - a cleaned version of the Quarterly Census of Employment and Wages, linked to State minimum wage data and other covariates

qwi.dta - a cleaned version of the Quarterly Worforce Indicators, linked to State minimum wage data and other covariates

*/

*------------------------------*
* SUMMARY STATISTICS           *
*------------------------------*

clear all
set more off

* BDS:

use bds , clear

sort statefips year
xtset statefips year
gen jg = D.emp
gen jgl = D.lemp

foreach var in emp jc jd jg popall {
replace `var'=`var'/1000
}

quietly estpost summarize mw realmw emp jg jgl jc jd popall share1559 rgspcap , detail
eststo sumstats_bds

* QCEW:

use qcew , clear
keep if industry == 10 // All ages in all industries in all sectors and ownership

sort statefips quarterly
xtset statefips quarterly
gen jg = D.emp
gen jgl = D.lemp

foreach var in emp jg popall {
replace `var'=`var'/1000
}

gen jc = . // Placeholder
gen jd = . // Placeholder

quietly estpost summarize mw realmw emp jg jgl jc jd popall share1559 rgspcap , detail
eststo sumstats_qcew

* QWI:

use qwi , clear
keep if industry == 10 & agegrp == 0 // All ages in all industries in all sectors and ownership

sort statefips quarterly
xtset statefips quarterly
gen jg = D.emp
gen jgl = D.lemp

foreach var in emp jg jc jd popall {
replace `var'=`var'/1000
}

quietly estpost summarize mw realmw emp jg jgl jc jd popall share1559 rgspcap , detail
eststo sumstats_qwi

#delimit ;
esttab sumstats_bds sumstats_qcew sumstats_qwi using appendix_table_sumstats_BDS_QCEW_QWI.csv , replace 
cells(`"mean(fmt(a2)) sd(fmt(a3)) p50(fmt(a2))"') 
label collabels("Mean" "Std. Dev." "Median") 
coeflabels(mw "State minimum wage (\$)" realmw "State minimum wage (\$real)" 
jg "Job growth (thousands)" jgl "Job growth (log)" emp "Jobs (thousands)" 
jc "Job creation (thousands)" jd "Job destruction (thousands)" 
popall "Population (thousands)" share1559 "Share aged 15-59" rgspcap "GSP/capita (\$real)")
nomtitles nonum
;
#delimit cr
