/* Last modified: January 20, 2015

*--------------------*
*    INPUT FILES     *
*--------------------*

Packages needed: estout - available from within Stata by typing "ssc install estout" or at http://repec.org/bocode/e/estout/esttab.html
	      
Files needed: 

bds.dta - a cleaned version of the Business Dyanamics Statistics, linked to State minimum wage data and other covariates

*/
*----------------------*
*   ROBUSTNESS CHECKS  *
*----------------------*

* Dist. Lag of First-differences model
* 1. Reproduce baseline result (no trends) from main results
* Falsification Tests:
* 2. 1-period lead of ln(MW)
* 3. 2-period lead of ln(MW)
* 4. Both 1-2 period leads of ln(MW)

* 5. Census Division by Time Fixed Effects
* 6. Drop observations that used minimum wage inflation indexing
* 7. Drop 2008-2010 Financial Crisis years

* Break-in-Trend model
* 1. Reproduce baseline result (with trends) from main results
* Falsification Tests:
* 2. I(next period change in MW)
* 3. 2-period lead of ln(MW)
* 4. 3-period lead of ln(MW)

* 5. Census Division by Time Fixed Effects
* 6. Drop observations that used minimum wage inflation indexing
* 7. Drop 2008-2010 Financial Crisis years


clear all
set more off
set matsize 4000

* BDS:

use bds , clear

* Add in 2012 nominal and log-real minimum wage values

keep statefips
duplicates drop
gen year = 2012
gen mw = .
gen lnmin = .
 replace mw = 7.25 if statefips == 1
 replace mw = 7.75 if statefips == 2
 replace mw = 7.65 if statefips == 4
 replace mw = 7.25 if statefips == 5
 replace mw = 8 if statefips == 6
 replace mw = 7.64 if statefips == 8
 replace mw = 8.25 if statefips == 9
 replace mw = 7.25 if statefips == 10
 replace mw = 8.25 if statefips == 11
 replace mw = 7.67 if statefips == 12
 replace mw = 7.25 if statefips == 13
 replace mw = 7.25 if statefips == 15
 replace mw = 7.25 if statefips == 16
 replace mw = 8.25 if statefips == 17
 replace mw = 7.25 if statefips == 18
 replace mw = 7.25 if statefips == 19
 replace mw = 7.25 if statefips == 20
 replace mw = 7.25 if statefips == 21
 replace mw = 7.25 if statefips == 22
 replace mw = 7.5 if statefips == 23
 replace mw = 7.25 if statefips == 24
 replace mw = 8 if statefips == 25
 replace mw = 7.4 if statefips == 26
 replace mw = 7.25 if statefips == 27
 replace mw = 7.25 if statefips == 28
 replace mw = 7.25 if statefips == 29
 replace mw = 7.65 if statefips == 30
 replace mw = 7.25 if statefips == 31
 replace mw = 8.25 if statefips == 32
 replace mw = 7.25 if statefips == 33
 replace mw = 7.25 if statefips == 34
 replace mw = 7.5 if statefips == 35
 replace mw = 7.25 if statefips == 36
 replace mw = 7.25 if statefips == 37
 replace mw = 7.25 if statefips == 38
 replace mw = 7.7 if statefips == 39
 replace mw = 7.25 if statefips == 40
 replace mw = 8.8 if statefips == 41
 replace mw = 7.25 if statefips == 42
 replace mw = 7.4 if statefips == 44
 replace mw = 7.25 if statefips == 45
 replace mw = 7.25 if statefips == 46
 replace mw = 7.25 if statefips == 47
 replace mw = 7.25 if statefips == 48
 replace mw = 7.25 if statefips == 49
 replace mw = 8.46 if statefips == 50
 replace mw = 7.25 if statefips == 51
 replace mw = 9.04 if statefips == 53
 replace mw = 7.25 if statefips == 54
 replace mw = 7.25 if statefips == 55
 replace mw = 7.25 if statefips == 56
 
 replace lnmin = 1.963741 if statefips == 1
 replace lnmin = 2.030432 if statefips == 2
 replace lnmin = 2.017445 if statefips == 4
 replace lnmin = 1.963741 if statefips == 5
 replace lnmin = 2.062181 if statefips == 6
 replace lnmin = 2.016137 if statefips == 8
 replace lnmin = 2.092953 if statefips == 9
 replace lnmin = 1.963741 if statefips == 10
 replace lnmin = 2.092953 if statefips == 11
 replace lnmin = 2.020056 if statefips == 12
 replace lnmin = 1.963741 if statefips == 13
 replace lnmin = 1.963741 if statefips == 15
 replace lnmin = 1.963741 if statefips == 16
 replace lnmin = 2.092953 if statefips == 17
 replace lnmin = 1.963741 if statefips == 18
 replace lnmin = 1.963741 if statefips == 19
 replace lnmin = 1.963741 if statefips == 20
 replace lnmin = 1.963741 if statefips == 21
 replace lnmin = 1.963741 if statefips == 22
 replace lnmin = 1.997643 if statefips == 23
 replace lnmin = 1.963741 if statefips == 24
 replace lnmin = 2.062181 if statefips == 25
 replace lnmin = 1.98422 if statefips == 26
 replace lnmin = 1.963741 if statefips == 27
 replace lnmin = 1.963741 if statefips == 28
 replace lnmin = 1.963741 if statefips == 29
 replace lnmin = 2.017445 if statefips == 30
 replace lnmin = 1.963741 if statefips == 31
 replace lnmin = 2.092953 if statefips == 32
 replace lnmin = 1.963741 if statefips == 33
 replace lnmin = 1.963741 if statefips == 34
 replace lnmin = 1.997643 if statefips == 35
 replace lnmin = 1.963741 if statefips == 36
 replace lnmin = 1.963741 if statefips == 37
 replace lnmin = 1.963741 if statefips == 38
 replace lnmin = 2.02396 if statefips == 39
 replace lnmin = 1.963741 if statefips == 40
 replace lnmin = 2.157491 if statefips == 41
 replace lnmin = 1.963741 if statefips == 42
 replace lnmin = 1.98422 if statefips == 44
 replace lnmin = 1.963741 if statefips == 45
 replace lnmin = 1.963741 if statefips == 46
 replace lnmin = 1.963741 if statefips == 47
 replace lnmin = 1.963741 if statefips == 48
 replace lnmin = 1.963741 if statefips == 49
 replace lnmin = 2.118089 if statefips == 50
 replace lnmin = 1.963741 if statefips == 51
 replace lnmin = 2.184399 if statefips == 53
 replace lnmin = 1.963741 if statefips == 54
 replace lnmin = 1.963741 if statefips == 55
 replace lnmin = 1.963741 if statefips == 56

append using bds

sort state year
xtset state year
fvset base 1 state // Setting some technical factor-variable settings
fvset base 1 year // Setting some technical factor-variable settings

estimates clear

gen delta_next = (f.mw > mw)
replace delta_next = . if year == 2012 // Not that this really matters for the estimations

gen year_sq = year^2

**********

*  Results for distributed lags (first difference of employment) model

estimates clear

qui reg D.lemp DL(0/3).lnmin i.year#i.censusreg D.lpopall D.share1559 D.lrgspcap , robust cluster(state)
estimates store col1

qui lincomest DL0.lnmin + DL1.lnmin + DL2.lnmin + DL3.lnmin
estimates store lincom1

qui reg D.lemp DL(0/3).lnmin DF.lnmin i.year#i.censusreg D.lpopall D.share1559 D.lrgspcap , robust cluster(state)
estimates store col2

qui lincomest DL0.lnmin + DL1.lnmin + DL2.lnmin + DL3.lnmin
estimates store lincom2

qui reg D.lemp DL(0/3).lnmin DF2.lnmin i.year#i.censusreg D.lpopall D.share1559 D.lrgspcap , robust cluster(state)
estimates store col3

qui lincomest DL0.lnmin + DL1.lnmin + DL2.lnmin + DL3.lnmin
estimates store lincom3

qui reg D.lemp DL(0/3).lnmin DF(1/2).lnmin i.year#i.censusreg D.lpopall D.share1559 D.lrgspcap , robust cluster(state)
estimates store col4

qui lincomest DL0.lnmin + DL1.lnmin + DL2.lnmin + DL3.lnmin
estimates store lincom4

qui reg D.lemp DL(0/3).lnmin i.year#i.censusdiv D.lpopall D.share1559 D.lrgspcap , robust cluster(state)
estimates store col5

qui lincomest DL0.lnmin + DL1.lnmin + DL2.lnmin + DL3.lnmin
estimates store lincom5

qui reg D.lemp DL(0/3).lnmin i.year#i.censusreg D.lpopall D.share1559 D.lrgspcap if indexedwage == 0 , robust cluster(state)
estimates store col6

qui lincomest DL0.lnmin + DL1.lnmin + DL2.lnmin + DL3.lnmin
estimates store lincom6

qui reg D.lemp DL(0/3).lnmin i.year#i.censusreg D.lpopall D.share1559 D.lrgspcap if year < 2008 , robust cluster(state)
estimates store col7

qui lincomest DL0.lnmin + DL1.lnmin + DL2.lnmin + DL3.lnmin
estimates store lincom7

#delimit ;
esttab col1 col2 col3 col4 col5 col6 col7
using table_robustness_DLFD_BDS.csv , replace b(4) se(3) label
keep(D.lnmin L*.lnmin F*.lnmin)
title( ) star(* 0.1 ** 0.05 *** 0.01)
nonotes nogap mtitles("Baseline results" 
"Leading values" "Leading values" "Leading values"
"Division by time"
"Inflation indexing" "Financial crisis")
;
#delimit cr

#delimit ;
esttab lincom1 lincom2 lincom3 lincom4 lincom5 lincom6 lincom7
using table_robustness_DLFD_BDS.csv , append b(4) se(3) star(* 0.1 ** 0.05 *** 0.01)
nonotes nogap noobs nomtitles
;
#delimit cr

**********

*  Results for break-in-trend model

gen tempmw = lnmin if year == 1977
egen initmw = min(tempmw) , by(statefips)
drop tempmw

qui reg D.lemp lnmin initmw i.year#i.censusreg D.lpopall D.share1559 D.lrgspcap ,  robust cluster(state)
estimates store col1

qui reg D.lemp lnmin initmw delta_next i.year#i.censusreg D.lpopall D.share1559 D.lrgspcap ,  robust cluster(state)
estimates store col2

qui reg D.lemp lnmin initmw f2.lnmin initmw i.year#i.censusreg D.lpopall D.share1559 D.lrgspcap ,  robust cluster(state)
estimates store col3

qui reg D.lemp lnmin initmw f3.lnmin initmw i.year#i.censusreg D.lpopall D.share1559 D.lrgspcap ,  robust cluster(state)
estimates store col4

qui reg D.lemp lnmin initmw i.year#i.censusdiv D.lpopall D.share1559 D.lrgspcap ,  robust cluster(state)
estimates store col5

qui reg D.lemp lnmin initmw i.year#i.censusreg D.lpopall D.share1559 D.lrgspcap if indexedwage == 0 ,  robust cluster(state)
estimates store col6

qui reg D.lemp lnmin initmw i.year#i.censusreg D.lpopall D.share1559 D.lrgspcap if year < 2008 ,  robust cluster(state)
estimates store col7




#delimit ;
esttab col1 col2 col3 col4 col5 col6 col7 
using table_robustness_BiT_BDS.csv , replace b(4) se(3) label
coeflabels(lnmin "BDS: FD in Log(emp) // Log of minimum wage"
delta_next "I(Delta MW t+1)" F2.lnmin "Log of MW t+2" 
F3.lnmin "Log of MW t+3")
title( ) star(* 0.1 ** 0.05 *** 0.01) keep(lnmin delta_next F2.lnmin F3.lnmin) 
nonotes nogap mtitles("Baseline results" 
"Leading values" "Leading values" "Leading values"
"Division by time" "Inflation indexing" "Financial crisis")
;
#delimit cr
